aerosoltools.aerosol2d.Aerosol2D.unnormalize_logdp — aerosoltools 0.1.0 documentation

# aerosoltools.aerosol2d.Aerosol2D.unnormalize_logdp

Aerosol2D.unnormalize_logdp(inplace=True)

  Reverse dlogDp normalization (e.g., convert dN/dlogDp to dN).

  ## Parameters

  inplacebool, optional

    If True, modifies current instance in-place. If False, returns a new instance with unnormalized data.

  ## Returns

  self or aerosolxd

    Instance with unnormalized size distribution data.

  Parameters:

    inplace (bool)